lineage Package
===============

Module
------

.. automodule:: lineage
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

lineage\.individual module
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: lineage.individual
    :members:
    :undoc-members:
    :show-inheritance:

lineage\.resources module
~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: lineage.resources
    :members:
    :undoc-members:
    :show-inheritance:

lineage\.visualization module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: lineage.visualization
    :members:
    :undoc-members:
    :show-inheritance:
